<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\Brand;
use App\Models\Product;
use App\Models\SubCategory;
use Illuminate\Http\Request;

class ProductController extends Controller
{
    public $resource = 'product';
    public $route = 'products';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $products = Product::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.product._table',compact('products'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        $subCategories = SubCategory::all();
        $brands = Brand::all();
        return view('admin.crud.product._create',compact('subCategories','brands'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('product_photo')  ) {
            $productPhoto = ImageHelper::add($request->product_photo, null, 'product_photo');
            $input['product_photo'] = $productPhoto;
        }
        Product::query()->create($input);
        return redirect()->route('dashboard.products.index')->with('success', 'Product added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $product = Product::query()->find($id);
        return view('admin.crud.product._show',compact('product'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function edit($id)
    {
        $product = Product::query()->find($id);
        $selectSubCategory = $product->sub_category_id;
        $subCategories = SubCategory::all();
        $brands = Brand::all();
        $selectBrand = $product->brand_id;
        return view('admin.crud.product._edit',compact('product','subCategories',
            'selectSubCategory','brands','selectBrand'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $product = Product::query()->find($id);
        $input = $request->all();

        if($request->hasFile('product_photo')  ) {
            $productPhoto = ImageHelper::add($request->product_photo, null, 'product_photo');
            $input['product_photo'] = $productPhoto;
        }
        if($request->hasFile('product_photos')  ) {
            $product_photos = [];
            try{
                foreach (json_decode($product->product_photos) as $p){
                    ImageHelper::delete($p);
                }
            }catch (\Exception $ex){

            }
            foreach ($request->file('product_photos') as $f){
                $photo = ImageHelper::add($f, null, 'product_photo');
                $product_photos[]= $photo;
            }
            $input['product_photos'] = $product_photos;
        }
        if(isset($input['colors']) && sizeof($input['colors']['color'])>0){
            $colors = [];
            foreach ($input['colors']['color'] as $key=>$c){
                $colors[]=[
                    'color'=>$c,
                    'name'=>$input['colors']['name'][$key],
                ];
            }
            $input['colors'] = $colors;
        }else{
            $input['colors'] = [];
        }
        $product->update($input);
        return redirect()->route('dashboard.products.index')->with('Slider updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Product::query()->find($id)->delete();
        return redirect()->route('dashboard.products.index')->with('success', 'Product added successfully');
    }

    public function deleteImage(Request $request)
    {
        $product = Product::query()->findOrFail($request->product_id);

        // Delete the existing identity photo
        if ($product->product_photo) {
            ImageHelper::delete($product->product_photo);
            $product->product_photo = 0;
            $product->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
