<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\Service;
use Illuminate\Http\Request;

class ServiceController extends Controller
{

//    public $search = 'service';
    public $resource = 'service';
    public $route = 'services';

    public function __construct()
    {
        view()->share('item', $this->resource);
//        view()->share('search', $this->search);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $services = Service::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.service._table',compact('services'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        return view('admin.crud.service._create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('service_photo')  ) {
            $servicePhoto = ImageHelper::add($request->service_photo, null, 'service_photo');
            $input['service_photo'] = $servicePhoto;
        }
        if($request->hasFile('service_photo_details')  ) {
            $servicePhotoDetails = ImageHelper::add($request->service_photo_details, null, 'service_photo');
            $input['service_photo_details'] = $servicePhotoDetails;
        }
        Service::query()->create($input);
        return redirect()->route('dashboard.services.index')->with('success', 'Slider added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $service = Service::query()->find($id);
        return  view('admin.crud.service._show' ,compact('service'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $service = Service::query()->find($id);
        return view('admin.crud.service._edit',compact('service'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update(Request $request, $id)
    {
        $service = Service::query()->find($id);
        $input = $request->all();

        if($request->hasFile('service_photo')  ) {
            $servicePhoto = ImageHelper::add($request->service_photo, null, 'service_photo');
            $input['service_photo'] = $servicePhoto;
        }
        if($request->hasFile('service_photo_details')  ) {
            $servicePhotoDetails = ImageHelper::add($request->service_photo_details, null, 'service_photo');
            $input['service_photo_details'] = $servicePhotoDetails;
        }
        $service->update($input);
        return redirect()->route('dashboard.services.index')->with('Slider updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        Service::query()->where('id',$id)->first()->delete();
        return redirect()->route('dashboard.services.index')->with('Slider deleted successfully');
    }

    public function deleteImage(Request $request)
    {
        $service = Service::query()->findOrFail($request->service_id);

        // Delete the existing identity photo
        if ($service->service_photo) {
            ImageHelper::delete($service->service_photo);
            $service->service_photo = 0;
            $service->save();

            return response()->json(['success' => true]);
        }

        if ($service->service_photo_details) {
            ImageHelper::delete($service->service_photo_details);
            $service->service_photo_details = 0;
            $service->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
