<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\SubCategory;
use Illuminate\Http\Request;

class SubCategoryController extends Controller
{

    public $resource = 'subCategory';
    public $route = 'subcategories';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $subCategories = SubCategory::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.subcategory._table',compact('subCategories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        $categories = Category::all();
        return  view('admin.crud.subcategory._create' ,compact('categories'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        SubCategory::query()->create($request->all());
        return  redirect()->route('dashboard.subcategories.index')->with('success', 'Sub Category added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function edit($id)
    {
        $subcategory = SubCategory::query()->find($id);
        $selectedSubCategory = $subcategory->category_id;
        $categories = Category::all();

        return view('admin.crud.subcategory._edit',compact('subcategory','categories','selectedSubCategory'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update(Request $request, $id)
    {
        $subcategory = SubCategory::query()->find($id);
        $subcategory->update($request->all());
        return  redirect()->route('dashboard.subcategories.index')->with('success', 'Sub Category Updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        SubCategory::query()->find($id)->delete();
        return  redirect()->route('dashboard.subcategories.index')->with('success', 'Sub Category deleted successfully');

    }
}
