<?php

namespace App\Http\Controllers\Front;

use App\Http\Controllers\Controller;
use App\Mail\OrderPlacedMail;
use App\Models\Brand;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Mail;

class ShopController extends Controller
{

    public function shop(Request $request)
    {

        $products = Product::query();

        if (request()->has('q') && strlen(request()->get('q')) > 0) {
            $products = $products->where('product_name', 'like', '%' . request()->get('q') . '%');
        }

        if (request()->has('cat') && is_numeric(request()->get('cat'))) {
            $products = $products->where('sub_category_id', request()->get('cat'));
        }

        if (request()->has('brand_id') && is_numeric(request()->get('brand_id'))) {
            $products = $products->where('brand_id', request()->get('brand_id'));
        }

        if (request()->has('min') && \request()->has('max')) {
            $min = str_replace('$', '', request()->get('min'));
            $max = str_replace('$', '', request()->get('max'));
            $products = $products
                ->where('price', '>=', $min)
                ->where('price', '<=', $max);
        }

        $products = $products->orderBy('id', 'desc')->paginate(12);

        $categories = Category::with('SubCategories')->get();
        $brands = Brand::all(); // Retrieve all brands

        return view('front.pages.shop', compact('products', 'categories', 'brands'));
    }

    public function brandFilter(Request $request)
    {
        $brand_id = $request->brand; // Get brand ID from request
        $query = Product::query();

        if ($brand_id) {
            $query->where('brand_id', $brand_id); // Filter products by brand
        }

        $products = $query->get(); // Get the filtered products or all products if no brand is selected
        $categories = Category::with('SubCategories')->get();
        $brands = Brand::all(); // Retrieve all brands

        return view('front.pages.shop_filter', compact('products', 'categories', 'brands'));
    }


    public function productDetails()
    {
        $product = Product::where('id', request()->get('id'))->first();
        return view('front.pages.product-details', ['product' => $product]);
    }

    public function checkout(Request $request)
    {
        $userData = $request->validate([
            'full_name' => 'required|string|max:100',
            'email' => 'nullable|string|max:20',
            'phone' => 'required|string|max:20',
            'address' => 'required|string|max:255',
            'cart' => 'required|json',
        ]);


        // Decode the cart JSON
        $cartItems = json_decode($userData['cart'], true);


        try {
            Mail::to('info@arabiamobiles.com')->send(new OrderPlacedMail($userData, $cartItems));
        } catch (\Exception $ex) {
            Log::info($ex->getMessage());
            return redirect()->back()->with('error', $ex->getMessage());
        }


        return redirect()->back()->with('success', 'Your message has been sent successfully!');
    }

    public function cart()
    {
        return view('front.pages.cart._cart');
    }
}
